@@ -14,6 +14,11 @@ class DateTimeEncoder(json.JSONEncoder):
             return super().default(z)
 
 
+def echo_dict(input_dict: dict):
+    for key, val in input_dict.items():
+        click.echo(f"{key[:18]+'..' if len(key)>17 else key}{(20-int(len(key)))*'.'}{val}")
+
+
 @click.group()
 @click.version_option()
 def cli():
@@ -21,74 +26,65 @@ def cli():
     pass
 
 
-@cli.command(name="command")
-@click.argument("example")
-@click.option(
-    "-o",
-    "--option",
-    help="An example option",
-)
-def first_command(example, option):
-    "Command description goes here"
-    click.echo("Here is some output")
-
-
 @cli.command()
 def ls():
     "list secrets in AWS Secrets Manager"
     resp = aws.get_secrets_list()
     for secret in resp.get("SecretList"):
         click.echo(f"\n-- {secret.get('Name')} --")
-        for key, val in secret.items():
-            click.echo(f"{key[:18]+'..' if len(key)>17 else key}{(20-int(len(key)))*'.'}{val}")
+        echo_dict(secret)
 
 
-# create
 @cli.command()
 @click.option("-s", "--secret-string", "secret_string", help="serialized json", required=True)
 @click.option("-n", "--secret-name", "secret_name", required=True)
-@click.option("-d", "--description", "description", required=False, default="string description")
-def create(secret_string, secret_name, description):
+def create(secret_string, secret_name):
     "create new secret"
-    # create_secret(self, secret_string, secret_name, description="string description")
-    click.echo("create secret method --> needs to be implemented")
+    aws.create(name=secret_name, secret_value=secret_string)
 
 
-# read
 @cli.command()
 @click.option("-n", "--secret-name", "secret_name", required=True)
-def read(description):
+def read(secret_name):
     "read contents of secret, metadata and secret_string"
-    click.echo("read secret method --> needs to be implemented")
-    # get and display metadata
+    resp = aws.describe(name=secret_name)
+    echo_dict(resp)
     value = click.prompt("display secret string? [Y/n]", type=str)
     if value.lower() == "y":
-        # get and display secret string
-        pass
+        click.echo(aws.get_value())
 
 
-# update
 @cli.command()
 @click.option("-s", "--secret-string", "secret_string", help="serialized json", required=True)
 @click.option("-n", "--secret-name", "secret_name", required=True)
-@click.option("-d", "--description", "description", required=False, default="string description")
-def update(secret_string, secret_name, description):
-    "change the contents of an existing secert"
-    click.echo("update secret method --> needs to be implemented")
+def update(secret_string, secret_name):  # , description):
+    "change or add the contents of an existing secert"
+    resp = aws.put_value(secret_value=secret_string, name=secret_name)
+    click.echo(resp)
 
 
-# delete
 @cli.command()
 @click.option("-n", "--secret-name", "secret_name", required=True)
-def delete(description):
+def delete(secret_name):
     "remove or archive a secret from AWS Secret Manager"
-    click.echo("delete secret method --> needs to be implemented")
+    resp = aws.delete(name=secret_name, without_recovery=False)
+    click.echo(resp)
+
+
+@cli.command()
+@click.option("-k", "--key-word", "key_word", required=True)
+def search(key_word):
+    "list secrets in AWS Secrets Manager with regex match"
+    resp = aws.get_secrets_list()
+    for secret in resp.get("SecretList"):
+        if key_word in secret.get("Name"):
+            click.echo(f"\n-- {secret.get('Name')} --")
+            echo_dict(secret)
 
 
-cli.add_command(first_command)
 cli.add_command(ls)
 cli.add_command(create)
 cli.add_command(read)
 cli.add_command(update)
 cli.add_command(delete)
-# cli.add_command(search)
+cli.add_command(search)
